Module backtraced

Module backtraced 

This module contains a backtraced error and its methods.

Structs

Backtraced
Backtraced compiler output type undefined value x –> file.leo: 2:8 = help: Initialize a variable x first.

Functions

compute_exit_code
Computes the exit code from a code identifier and error code.
format_error_code
Formats a unique error identifier string.
format_warning_code
Formats a unique warning identifier string.