pub enum LeoError {
Show 15 variants
AstError(AstError),
CliError(CliError),
CompilerError(CompilerError),
ConstEvalError(ConstEvalError),
PackageError(PackageError),
ParserError(ParserError),
StaticAnalyzerError(StaticAnalyzerError),
TypeCheckerError(TypeCheckerError),
NameValidationError(NameValidationError),
CheckInterfacesError(CheckInterfacesError),
LoopUnrollerError(LoopUnrollerError),
FlattenError(FlattenError),
LastErrorCode(i32),
UtilError(UtilError),
Anyhow(Error),
}Expand description
The LeoError type that contains all sub error types. This allows a unified error type throughout the Leo crates.
Variants
AstError(AstError)
Represents an AST Error in a Leo Error.
CliError(CliError)
Represents a CLI Error in a Leo Error.
CompilerError(CompilerError)
Represents a Compiler Error in a Leo Error.
ConstEvalError(ConstEvalError)
Represents a Constant Evaluation Error in a Leo Error.
PackageError(PackageError)
Represents a Package Error in a Leo Error.
ParserError(ParserError)
Represents a Parser Error in a Leo Error.
StaticAnalyzerError(StaticAnalyzerError)
Represents a Static Analyzer Error in a Leo Error.
TypeCheckerError(TypeCheckerError)
Represents a Type Checker Error in a Leo Error.
NameValidationError(NameValidationError)
Represents a Name Validation Error in a Leo Error.
CheckInterfacesError(CheckInterfacesError)
Represents a Check Interfaces Error in a Leo Error.
LoopUnrollerError(LoopUnrollerError)
Represents a Loop Unroller Error in a Leo Error.
FlattenError(FlattenError)
Represents a Flatten Error in a Leo Error.
LastErrorCode(i32)
Purely for just exiting with the correct status code and not re-displaying an error.
UtilError(UtilError)
Represents a Utils Error in a Leo Error.
Anyhow(Error)
Anyhow errors.
Implementations