Enum leo_errors::errors::LeoError
source · pub enum LeoError {
AstError(AstError),
CliError(CliError),
CompilerError(CompilerError),
InputError(InputError),
PackageError(PackageError),
ParserError(ParserError),
TypeCheckerError(TypeCheckerError),
FlattenError(FlattenError),
LastErrorCode(i32),
Anyhow(Error),
}Expand description
The LeoError type that contains all sub error types. This allows a unified error type throughout the Leo crates.
Variants
AstError(AstError)
Represents an AST Error in a Leo Error.
CliError(CliError)
Represents an CLI Error in a Leo Error.
CompilerError(CompilerError)
Represents an Compiler Error in a Leo Error.
InputError(InputError)
Represents an Input Error in a Leo Error.
PackageError(PackageError)
Represents an Package Error in a Leo Error.
ParserError(ParserError)
Represents an Parser Error in a Leo Error.
TypeCheckerError(TypeCheckerError)
Represents a Type Checker Error in a Leo Error.
FlattenError(FlattenError)
Represents a Flatten Error in a Leo Error.
LastErrorCode(i32)
Purely for just exiting with the correct status code and not re-displaying an error.
Anyhow(Error)
Anyhow errors.
Implementations