Enum leo_errors::errors::input::input_errors::InputError
source · pub enum InputError {
Formatted(Formatted),
Backtraced(Backtraced),
}Expand description
InputError enum that represents all the errors for the inputs part of leo-ast crate.
Variants
Formatted(Formatted)
Backtraced(Backtraced)
Implementations
sourceimpl InputError
impl InputError
sourcepub fn unexpected_type(
expected: impl Display,
received: impl Display,
span: Span
) -> Self
pub fn unexpected_type(
expected: impl Display,
received: impl Display,
span: Span
) -> Self
For when declared variable type mismatches actual type.
sourcepub fn illegal_expression(expr: impl Display, span: Span) -> Self
pub fn illegal_expression(expr: impl Display, span: Span) -> Self
For when the expression is not allowed in an input file.
sourcepub fn unexpected_section(
expected: &[impl Display],
received: impl Display,
span: Span
) -> Self
pub fn unexpected_section(
expected: &[impl Display],
received: impl Display,
span: Span
) -> Self
For when section name is not an allowed one.
pub fn num_exit_codes() -> i32