Enum leo_errors::warnings::parser::parser_warning::ParserWarning
source · pub enum ParserWarning {
Formatted(Formatted),
Backtraced(Backtraced),
}Expand description
ParserWarning enum that represents all the warnings for the leo-parser crate.
Variants
Formatted(Formatted)
Backtraced(Backtraced)
Implementations
sourceimpl ParserWarning
impl ParserWarning
sourcepub fn const_parameter_or_input(span: Span) -> Self
pub fn const_parameter_or_input(span: Span) -> Self
For when a user used const on a parameter or input instead of constant.
pub fn num_exit_codes() -> i32