This module contains a backtraced error and its methods.
Structs
- Backtraced
- Backtraced compiler output type
undefined value
x–> file.leo: 2:8 = help: Initialize a variablexfirst.
Functions
- compute_
exit_ code - Computes the exit code from a code identifier and error code.
- format_
error_ code - Formats a unique error identifier string.
- format_
warning_ code - Formats a unique warning identifier string.