Module leo_errors::common::formatted
source · Expand description
This module contains a formatted error and its methods.
Structs
Formatted compiler error type
undefined value
x
–> file.leo: 2:8
|
2 | let a = x;
| ^
|
= help: Initialize a variable x first.
Makes use of the same fields as a BacktracedError.