Module leo_errors::emitter

source ·
Contains traits and types for channels through which errors go.

Structs

A buffer of Ts.
An Emitter that collects into a list.
A handler deals with errors and other compiler output.
A trivial Emitter using the standard error.

Traits

Types that are sinks for compiler errors.

Type Definitions

A buffer of LeoErrors.
A buffer of LeoWarnings.