Struct leo_errors::emitter::Handler

source ·
pub struct Handler { /* private fields */ }
A handler deals with errors and other compiler output.

Implementations

Construct a Handler using the given emitter.

Construct a Handler that will append to buf.

Runs logic provided a handler that collects all errors into the String, or if there were none, returns some T.

Emit the error err.

Emit the error err.

Emits the error err. This will immediately abort compilation.

The number of errors thus far.

The number of warnings thus far.

Did we have any errors thus far?

Gets the last emitted error’s exit code if it exists. Then exits the program with it if it did exist.

Extend handler with error given res = Err(error).