Handler

Struct Handler 

pub struct Handler { /* private fields */ }
A handler deals with errors and other compiler output.

Implementations

Source

impl Handler

pub fn new<T: 'static + Emitter>(emitter: T) -> Self

Construct a Handler using the given emitter.

pub fn new_with_buf() -> (Self, BufferEmitter)

Construct a Handler that will append to buf.

pub fn with<T>( logic: impl for<'a> FnOnce(&'a Handler) -> Result<T, LeoError>, ) -> Result<T, ErrBuffer>

Runs logic provided a handler that collects all errors into the String, or if there were none, returns some T.

pub fn emit_err(&self, err: impl Into<LeoError>)

Emit the error err.

pub fn emit_warning(&self, warning: impl Into<LeoWarning>)

Emit the error err.

pub fn emit_warning_once(&self, span: Span, warning: impl Into<LeoWarning>)

Emit a warning only once per span. Subsequent calls with the same span are ignored.

pub fn err_count(&self) -> usize

The number of errors thus far.

pub fn warning_count(&self) -> usize

The number of warnings thus far.

pub fn had_errors(&self) -> bool

Did we have any errors thus far?

pub fn last_err(&self) -> Result<(), LeoError>

Gets the last emitted error’s exit code if it exists. Then exits the program with it if it did exist.

pub fn extend_if_error<T>(&self, res: Result<T, LeoError>) -> Result<T, ()>

Extend handler with error given res = Err(error).